/**
  *  \file featureset.cpp
  *  \brief FeatureSet class implementation
  *  \author Stefan Reuther
  */

#include "featureset.h"
#include "util.h"

/** Constructor. Builds a blank feature set. */
FeatureSet::FeatureSet()
{ }

/** Constructor. Builds a feature set containing the features
    specified in \c s. \see assignFromString() */
FeatureSet::FeatureSet(std::string s)
{
    assignFromString(s);
}

/** Assign feature set from string.
    \param s List of features, comma-separated token list */
void
FeatureSet::assignFromString(std::string s)
{
    std::string::size_type n;
    std::set<std::string>().swap(m_Features);
    while ((n = s.find(',')) != s.npos) {
        std::string me = strTrim(s.substr(0, n));
        if (me.size())
            add(me);
        s.erase(0, n+1);
    }
    std::string me = strTrim(s);
    if (me.size())
        add(me);
}

/** Convert to string.
    \returns comma-separated token list */
std::string
FeatureSet::toString() const
{
    std::string result;
    std::set<std::string>::const_iterator i = m_Features.begin(), e = m_Features.end();
    if (i != e) {
        result.append(*i);
        while (++i != e) {
            result.append(",");
            result.append(*i);
        }
    }
    return result;
}

/** Check whether we support a feature.
    \param what Feature to query */
bool
FeatureSet::contains(std::string what) const
{
    return m_Features.find(what) != m_Features.end();
}

/** Add a feature.
    \param what Feature to add */
void
FeatureSet::add(std::string what)
{
    m_Features.insert(what);
}
