/**
  *  \file game.h
  *  \brief Game class declaration
  *  \author Stefan Reuther
  */
#ifndef GAME_H_INCLUDED
#define GAME_H_INCLUDED

#include <string>
#include <vector>
#include "propertyobject.h"
#include "featureset.h"

class Race;
class Expander;

/** Game definition. */
class Game : public PropertyObject {
    std::string m_Name;

    std::string m_LocalDir;

    std::string m_GameUrl;

    std::string m_SpecUrl;

    std::string m_MapUrl;

    std::string m_HostDir;

    FeatureSet m_UsedFeatures;

    std::vector<Race*> m_Races;
 public:

    Game(std::string name);

    ~Game();

    void enumerate(KVEnumerator& e);

    bool assign(std::string name, std::string value, LoaderState& st);

    PropertyObject* createSubtree(std::string name, std::string value, LoaderState& st);

    std::string getName() const
        { return m_Name; }

    void addRace(Race* r);

    Race* getRaceByNumber(int nr);

    Race* getDefaultRace();

    void enumerateRaces(ValueEnumerator<Race>& r);

    std::string getGameUrl() const
        { return m_GameUrl; }

    std::string getSpecificationUrl() const
        { return m_SpecUrl; }

    std::string getMapUrl() const
        { return m_MapUrl; }

    std::string getLocalDirectory() const
        { return m_LocalDir; }

    void setLocalDirectory(std::string dir)
        { m_LocalDir = dir; }
};

#endif
